You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by nt...@apache.org on 2015/12/29 08:17:54 UTC

[01/12] ignite git commit: ignite-1.5 Added node attributes in AuthenticationContext.

Repository: ignite
Updated Branches:
  refs/heads/ignite-gg-10837 9f7b14e84 -> 7bc1501eb


ignite-1.5 Added node attributes in AuthenticationContext.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/939a170d
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/939a170d
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/939a170d

Branch: refs/heads/ignite-gg-10837
Commit: 939a170d9d27822b0ed19b019ecf8c76142c544d
Parents: 18c413c
Author: sboikov <sb...@gridgain.com>
Authored: Mon Dec 28 12:10:53 2015 +0300
Committer: sboikov <sb...@gridgain.com>
Committed: Mon Dec 28 12:10:53 2015 +0300

----------------------------------------------------------------------
 .../apache/ignite/internal/IgniteKernal.java    |  7 +++--
 .../ignite/internal/IgniteNodeAttributes.java   |  3 ++
 .../processors/rest/GridRestProcessor.java      |  4 +++
 .../rest/client/message/GridClientNodeBean.java |  4 +--
 .../plugin/security/AuthenticationContext.java  | 33 +++++++++++++++++---
 5 files changed, 42 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/939a170d/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
index 6e0be10..14b5816 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgniteKernal.java
@@ -788,7 +788,7 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
 
             startProcessor(new ClusterProcessor(ctx));
 
-            fillNodeAttributes();
+            fillNodeAttributes(notifyEnabled);
 
             U.onGridStart();
 
@@ -1201,10 +1201,11 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
     /**
      * Creates attributes map and fills it in.
      *
+     * @param notifyEnabled Update notifier flag.
      * @throws IgniteCheckedException thrown if was unable to set up attribute.
      */
     @SuppressWarnings({"SuspiciousMethodCalls", "unchecked", "TypeMayBeWeakened"})
-    private void fillNodeAttributes() throws IgniteCheckedException {
+    private void fillNodeAttributes(boolean notifyEnabled) throws IgniteCheckedException {
         final String[] incProps = cfg.getIncludeProperties();
 
         try {
@@ -1242,6 +1243,8 @@ public class IgniteKernal implements IgniteEx, IgniteMXBean, Externalizable {
                 }
             }
 
+            ctx.addNodeAttribute(IgniteNodeAttributes.ATTR_UPDATE_NOTIFIER_ENABLED, notifyEnabled);
+
             if (log.isDebugEnabled())
                 log.debug("Added system properties to node attributes.");
         }

http://git-wip-us.apache.org/repos/asf/ignite/blob/939a170d/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java b/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
index ba04403..3c5f960 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/IgniteNodeAttributes.java
@@ -144,6 +144,9 @@ public final class IgniteNodeAttributes {
     /** Binary protocol version. */
     public static final String ATTR_BINARY_PROTO_VER = ATTR_PREFIX + ".binary.proto.ver";
 
+    /** Update notifier enabled. */
+    public static final String ATTR_UPDATE_NOTIFIER_ENABLED = ATTR_PREFIX + ".update.notifier.enabled";
+
     /**
      * Enforces singleton.
      */

http://git-wip-us.apache.org/repos/asf/ignite/blob/939a170d/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/GridRestProcessor.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/GridRestProcessor.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/GridRestProcessor.java
index 4bb02c4..e839443 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/GridRestProcessor.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/GridRestProcessor.java
@@ -22,6 +22,7 @@ import java.lang.reflect.InvocationTargetException;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.EnumMap;
 import java.util.HashMap;
 import java.util.List;
@@ -656,6 +657,7 @@ public class GridRestProcessor extends GridProcessorAdapter {
 
         authCtx.subjectType(REMOTE_CLIENT);
         authCtx.subjectId(req.clientId());
+        authCtx.nodeAttributes(Collections.<String, Object>emptyMap());
 
         SecurityCredentials cred;
 
@@ -884,11 +886,13 @@ public class GridRestProcessor extends GridProcessorAdapter {
 
         /** Session token id. */
         private final UUID sesId;
+
         /**
          * Time when session is used last time.
          * If this time was set at TIMEDOUT_FLAG, then it should never be changed.
          */
         private final AtomicLong lastTouchTime = new AtomicLong(U.currentTimeMillis());
+
         /** Security context. */
         private volatile SecurityContext secCtx;
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/939a170d/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/client/message/GridClientNodeBean.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/client/message/GridClientNodeBean.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/client/message/GridClientNodeBean.java
index 8ba6eb5..ca82608 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/client/message/GridClientNodeBean.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/rest/client/message/GridClientNodeBean.java
@@ -233,8 +233,8 @@ public class GridClientNodeBean implements Externalizable {
             for (GridClientCacheBean cacheBean : caches) {
                 if (cacheBean.getName() == null)
                     dfltCacheMode = cacheBean.getMode().toString();
-                else
-                    cacheMap.put(cacheBean.getName(), cacheBean.getMode().toString());
+
+                cacheMap.put(cacheBean.getName(), cacheBean.getMode().toString());
             }
         }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/939a170d/modules/core/src/main/java/org/apache/ignite/plugin/security/AuthenticationContext.java
----------------------------------------------------------------------
diff --git a/DEVNOTES.txt b/DEVNOTES.txt
index 784be96..ee982e4 100644
--- a/DEVNOTES.txt
+++ b/DEVNOTES.txt
@@ -12,6 +12,14 @@ With LGPL dependencies:
 With LGPL dependencies and Scala 2.10:
   mvn clean package -DskipTests -Prelease,lgpl -Dignite.edition=fabric-lgpl -Dscala-2.10
 
+With Apache Ignite.NET:
+  Build Apache Ignite.NET as described at modules/platforms/dotnet/DEVNOTES.txt.
+
+  Then build Ignite Fabric with Apache Ignite.NET:
+  mvn clean package -DskipTests -DclientDocs
+
+  Note that 'doxygen' should be installed before running this command.
+
 Look for apache-ignite-fabric-<version>-bin.zip in ./target/bin directory.
 
 NOTE: JDK version should be 1.7.0-* or >= 1.8.0-u40.

http://git-wip-us.apache.org/repos/asf/ignite/blob/23d7e251/modules/platforms/dotnet/Apache.Ignite.sln
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.sln b/modules/platforms/dotnet/Apache.Ignite.sln
index 5c6ce05..164f388 100644
--- a/modules/platforms/dotnet/Apache.Ignite.sln
+++ b/modules/platforms/dotnet/Apache.Ignite.sln
@@ -1,5 +1,4 @@
-
-Microsoft Visual Studio Solution File, Format Version 11.00
+Microsoft Visual Studio Solution File, Format Version 11.00
 # Visual Studio 2010
 Project("{FAE04EC0-301F-11D3-BF4B-00C04F79EFBC}") = "Apache.Ignite.Core", "Apache.Ignite.Core\Apache.Ignite.Core.csproj", "{4CD2F726-7E2B-46C4-A5BA-057BB82EECB6}"
 EndProject
@@ -26,10 +25,12 @@ Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Solution Items", "Solution
 		Apache.Ignite.FxCop = Apache.Ignite.FxCop
 		Apache.Ignite.sln.DotSettings = Apache.Ignite.sln.DotSettings
 		build.bat = build.bat
+		DEVNOTES.txt = DEVNOTES.txt
 		examples\Config\example-cache-query.xml = examples\Config\example-cache-query.xml
 		examples\Config\example-cache-store.xml = examples\Config\example-cache-store.xml
 		examples\Config\example-cache.xml = examples\Config\example-cache.xml
 		examples\Config\example-compute.xml = examples\Config\example-compute.xml
+		README.txt = README.txt
 	EndProjectSection
 EndProject
 Global

http://git-wip-us.apache.org/repos/asf/ignite/blob/23d7e251/modules/platforms/dotnet/DEVNOTES.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/DEVNOTES.txt b/modules/platforms/dotnet/DEVNOTES.txt
new file mode 100644
index 0000000..5650283
--- /dev/null
+++ b/modules/platforms/dotnet/DEVNOTES.txt
@@ -0,0 +1,18 @@
+Apache Ignite.NET Build Instructions
+====================================
+
+Requirements:
+* Windows (XP and up), Windows Server (2008 and up)
+* Oracle JDK 7 and above
+* .NET Framework 4.0
+* Visual Studio 2010 (later versions require upgrading "common" C++ project, see below)
+* JAVA_HOME environment variable set to the corresponding JDK (x64 or x86).
+
+Building binaries:
+  msbuild Apache.Ignite.sln /p:Configuration=Release /p:Platform=x64
+Resulting binaries will be in Apache.Ignite\bin folder
+
+Building in later versions of Visual Studio:
+* Open Apache.Ignite.sln in Visual Studio
+* You will be prompted to "Update VC++ Compiler and Libraries", click "Update"
+* OR, right-click "common" project in the Solution Explorer and select "Upgrade VC++ Compiler and Libraries"
\ No newline at end of file


[11/12] ignite git commit: RAT fix

Posted by nt...@apache.org.
RAT fix


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/f97dc9fe
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/f97dc9fe
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/f97dc9fe

Branch: refs/heads/ignite-gg-10837
Commit: f97dc9fe399792ff81fc936a47704c6d62656bd8
Parents: 156e787
Author: Anton Vinogradov <av...@apache.org>
Authored: Mon Dec 28 17:15:59 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 17:15:59 2015 +0300

----------------------------------------------------------------------
 parent/pom.xml | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/f97dc9fe/parent/pom.xml
----------------------------------------------------------------------
diff --git a/parent/pom.xml b/parent/pom.xml
index b7b417b..4497d01 100644
--- a/parent/pom.xml
+++ b/parent/pom.xml
@@ -826,7 +826,7 @@
                                         <exclude>**/keystore/*.pfx</exclude><!--bin-files-->
                                         <!--special excludes-->
                                         <exclude>idea/ignite_codeStyle.xml</exclude>
-                                        <exclude>DEVNOTES.txt</exclude>
+                                        <exclude>**/DEVNOTES.txt</exclude>
                                         <exclude>**/NOTICE*</exclude>
                                         <exclude>**/LICENSE*</exclude>
                                         <exclude>src/main/java/org/apache/ignite/internal/util/offheap/unsafe/GridOffHeapSnapTreeMap.java</exclude><!--BSD license-->


[10/12] ignite git commit: Add Camel Streamer and OSGi to release notes.

Posted by nt...@apache.org.
Add Camel Streamer and OSGi to release notes.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/156e7879
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/156e7879
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/156e7879

Branch: refs/heads/ignite-gg-10837
Commit: 156e7879eeff34ec7ee5256dac6adb91c9b4fc9b
Parents: 46b8f01
Author: Raul Kripalani <ra...@apache.org>
Authored: Mon Dec 28 13:30:44 2015 +0000
Committer: Raul Kripalani <ra...@apache.org>
Committed: Mon Dec 28 13:30:53 2015 +0000

----------------------------------------------------------------------
 RELEASE_NOTES.txt | 2 ++
 1 file changed, 2 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/156e7879/RELEASE_NOTES.txt
----------------------------------------------------------------------
diff --git a/RELEASE_NOTES.txt b/RELEASE_NOTES.txt
index b0822c9..2e9625e 100644
--- a/RELEASE_NOTES.txt
+++ b/RELEASE_NOTES.txt
@@ -11,6 +11,8 @@ Apache Ignite In-Memory Data Fabric 1.5
 * Added MQTT Streamer.
 * Added Twitter Streamer.
 * Added Ignite Sink (integration with Apache Flume).
+* Added Apache Camel Streamer.
+* Added OSGi support.
 * Fixed optimistic serializable transactions: implemented "deadlock-free" locking algorithm.
 * Fixed failover for continuous queries.
 * Fixed compilation and runtime errors under OpenJDK and IBM JDK.


[07/12] ignite git commit: IGNITE-2305

Posted by nt...@apache.org.
IGNITE-2305


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/ed8f9fce
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/ed8f9fce
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/ed8f9fce

Branch: refs/heads/ignite-gg-10837
Commit: ed8f9fce4fdffc170f9f4a3aae53804eb8248e5e
Parents: 4f2c751
Author: Anton Vinogradov <av...@apache.org>
Authored: Mon Dec 28 15:56:04 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 15:56:04 2015 +0300

----------------------------------------------------------------------
 DEVNOTES.txt | 3 +++
 1 file changed, 3 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/ed8f9fce/DEVNOTES.txt
----------------------------------------------------------------------
diff --git a/DEVNOTES.txt b/DEVNOTES.txt
index ee982e4..3e19243 100644
--- a/DEVNOTES.txt
+++ b/DEVNOTES.txt
@@ -37,6 +37,9 @@ assembly will also include integration module for Apache Spark.
 
 NOTE: JDK version should be 1.7.0-* or >= 1.8.0-u40.
 
+Ignite C++ Build Instructions
+======================================
+  Instructions can be found at modules/platforms/cpp/DEVNOTES.txt.
 
 Ignite Release Instructions
 ===========================


[08/12] ignite git commit: IGNITE-2306: CPP: Added standalone node project to published solutions.

Posted by nt...@apache.org.
IGNITE-2306: CPP: Added standalone node project to published solutions.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/f023c051
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/f023c051
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/f023c051

Branch: refs/heads/ignite-gg-10837
Commit: f023c051b46811eece46b97fa040bee07ce474d3
Parents: ed8f9fc
Author: isapego <is...@gridgain.com>
Authored: Mon Dec 28 16:17:05 2015 +0300
Committer: vozerov-gridgain <vo...@gridgain.com>
Committed: Mon Dec 28 16:17:05 2015 +0300

----------------------------------------------------------------------
 modules/platforms/cpp/project/vs/ignite.sln        |  6 ++----
 modules/platforms/cpp/project/vs/ignite.slnrel     | 10 ++++++++++
 modules/platforms/cpp/project/vs/ignite_x86.slnrel | 10 ++++++++++
 3 files changed, 22 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/f023c051/modules/platforms/cpp/project/vs/ignite.sln
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/project/vs/ignite.sln b/modules/platforms/cpp/project/vs/ignite.sln
index c573606..8b561e6 100644
--- a/modules/platforms/cpp/project/vs/ignite.sln
+++ b/modules/platforms/cpp/project/vs/ignite.sln
@@ -1,8 +1,6 @@
 
-Microsoft Visual Studio Solution File, Format Version 12.00
-# Visual Studio 2013
-VisualStudioVersion = 12.0.31101.0
-MinimumVisualStudioVersion = 10.0.40219.1
+Microsoft Visual Studio Solution File, Format Version 11.00
+# Visual Studio 2010
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "common", "..\..\common\project\vs\common.vcxproj", "{4F7E4917-4612-4B96-9838-025711ADE391}"
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "core", "..\..\core\project\vs\core.vcxproj", "{E2DEA693-F2EA-43C2-A813-053378F6E4DB}"

http://git-wip-us.apache.org/repos/asf/ignite/blob/f023c051/modules/platforms/cpp/project/vs/ignite.slnrel
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/project/vs/ignite.slnrel b/modules/platforms/cpp/project/vs/ignite.slnrel
index 7456097..8b7ad35 100644
--- a/modules/platforms/cpp/project/vs/ignite.slnrel
+++ b/modules/platforms/cpp/project/vs/ignite.slnrel
@@ -5,6 +5,8 @@ Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "common", "..\..\common\proj
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "core", "..\..\core\project\vs\core.vcxproj", "{E2DEA693-F2EA-43C2-A813-053378F6E4DB}"
 EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "ignite", "..\..\ignite\project\vs\ignite.vcxproj", "{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}"
+EndProject
 Global
 	GlobalSection(SolutionConfigurationPlatforms) = preSolution
 		Release|x64 = Release|x64
@@ -26,6 +28,14 @@ Global
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|Win32.Build.0 = Release|Win32
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|x64.ActiveCfg = Release|x64
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|x64.Build.0 = Release|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|Win32.ActiveCfg = Debug|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|Win32.Build.0 = Debug|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|x64.ActiveCfg = Debug|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|x64.Build.0 = Debug|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|Win32.ActiveCfg = Release|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|Win32.Build.0 = Release|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|x64.ActiveCfg = Release|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|x64.Build.0 = Release|x64
 	EndGlobalSection
 	GlobalSection(SolutionProperties) = preSolution
 		HideSolutionNode = FALSE

http://git-wip-us.apache.org/repos/asf/ignite/blob/f023c051/modules/platforms/cpp/project/vs/ignite_x86.slnrel
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/project/vs/ignite_x86.slnrel b/modules/platforms/cpp/project/vs/ignite_x86.slnrel
index b716b49..59c5434 100644
--- a/modules/platforms/cpp/project/vs/ignite_x86.slnrel
+++ b/modules/platforms/cpp/project/vs/ignite_x86.slnrel
@@ -5,6 +5,8 @@ Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "common", "..\..\common\proj
 EndProject
 Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "core", "..\..\core\project\vs\core.vcxproj", "{E2DEA693-F2EA-43C2-A813-053378F6E4DB}"
 EndProject
+Project("{8BC9CEB8-8B4A-11D0-8D11-00A0C91BC942}") = "ignite", "..\..\ignite\project\vs\ignite.vcxproj", "{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}"
+EndProject
 Global
 	GlobalSection(SolutionConfigurationPlatforms) = preSolution
 		Release|Win32 = Release|Win32
@@ -26,6 +28,14 @@ Global
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|Win32.Build.0 = Release|Win32
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|x64.ActiveCfg = Release|x64
 		{E2DEA693-F2EA-43C2-A813-053378F6E4DB}.Release|x64.Build.0 = Release|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|Win32.ActiveCfg = Debug|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|Win32.Build.0 = Debug|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|x64.ActiveCfg = Debug|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Debug|x64.Build.0 = Debug|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|Win32.ActiveCfg = Release|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|Win32.Build.0 = Release|Win32
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|x64.ActiveCfg = Release|x64
+		{69688B4D-3EE0-43F5-A1C6-29B5D2DDE949}.Release|x64.Build.0 = Release|x64
 	EndGlobalSection
 	GlobalSection(SolutionProperties) = preSolution
 		HideSolutionNode = FALSE


[05/12] ignite git commit: IGNITE-2305: Fix for README.txt

Posted by nt...@apache.org.
IGNITE-2305: Fix for README.txt

Signed-off-by: Anton Vinogradov <av...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/4f2c7517
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/4f2c7517
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/4f2c7517

Branch: refs/heads/ignite-gg-10837
Commit: 4f2c75177cc6e7c06b30f66ec20397ae59fea6bb
Parents: cdda4b5
Author: isapego <is...@gridgain.com>
Authored: Mon Dec 28 15:42:07 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 15:50:40 2015 +0300

----------------------------------------------------------------------
 modules/platforms/cpp/DEVNOTES.txt | 35 ++++----------------------
 modules/platforms/cpp/README.txt   | 44 ++++++++++++++++++++++++++++++++-
 2 files changed, 48 insertions(+), 31 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/4f2c7517/modules/platforms/cpp/DEVNOTES.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/DEVNOTES.txt b/modules/platforms/cpp/DEVNOTES.txt
index c97d04c..9a09333 100644
--- a/modules/platforms/cpp/DEVNOTES.txt
+++ b/modules/platforms/cpp/DEVNOTES.txt
@@ -38,18 +38,6 @@ Building the library:
 NOTE: "make install" command may require superuser privileges. In this case it must be
 executed as "sudo make install".
 
-Development:
-
- * IGNITE_HOME environment variable must be set to Ignite installation directory.
- * Once both libraries are built and installed, required headers are placed in the
-   "/usr/local/include/ignite" directory.
- * Apache Ignite C++ depends on jni.h file located inside ${JAVA_HOME}/include directory.
-   Add this directory to headers search path: "-I${JAVA_HOME}/include".
- * Library is placed in the "/usr/local/lib" directory. Link it to your project: "-lignite".
- * Ignite depends on "libjvm.so" library shipped with Java. Typically this library is located inside
-   $JAVA_HOME/jre/lib/amd64/server directory. Ensure that LD_LIBRARY_PATH environment variable points to this directory.
-
-
 Building on Windows with Visual Studio (tm)
 ----------------------------------
 
@@ -60,25 +48,12 @@ Common Requirements:
  * Java Development Kit (JDK) must be installed: https://java.com/en/download/index.jsp
  * JAVA_HOME environment variable must be set pointing to Java installation directory.
 
-Building the library:
+Building binaries:
 
  * Open and build %IGNITE_HOME%\platforms\cpp\project\vs\ignite.sln (or ignite_86.sln if you are running
    32-bit platform).
 
-Development:
-
- * IGNITE_HOME environment variable must be set to Ignite installation directory.
- * Update Include Directories in Project Properties with paths to:
-   * $(IGNITE_HOME)\platforms\cpp\core\include
-   * $(IGNITE_HOME)\platforms\cpp\core\os\win\include
-   * $(IGNITE_HOME)\platforms\cpp\common\include
-   * $(IGNITE_HOME)\platforms\cpp\common\os\win\include
-   * $(JAVA_HOME)\include
-   * $(JAVA_HOME)\include\win32
- * Update Library Directories with path to the built binaries
- * Update Linker\Input\Additional Dependencies in Project Properties with path to
-   * ignite.common.lib
-   * ignite.core.lib
- * Make sure that your application is aware about ignite.common.dll and ignite.core.dll libraries. The easiest way
-   to achieve this is to either make sure these files are in %PATH%, or to put them into the output directory of
-   your project with help of PostBuild events.
\ No newline at end of file
+Building in later versions of Visual Studio:
+ * Open project\vs\ignite.sln or project\vs\ignite_86.sln in Visual Studio
+ * You will be prompted to "Update VC++ Compiler and Libraries", click "Update"
+ * Build the solution.
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/4f2c7517/modules/platforms/cpp/README.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/README.txt b/modules/platforms/cpp/README.txt
index 74dec60..e542c82 100644
--- a/modules/platforms/cpp/README.txt
+++ b/modules/platforms/cpp/README.txt
@@ -18,8 +18,50 @@ Support for the following will be added in next releases:
 
 Full source code is provided. Users should build the library for intended platform.
 
-Output files list:
+Linux info
+==============
+
+Files list:
+
+ * ignite - executable to start standalone Ignite C++ node.
+ * libignite.so - Ignite C++ API library.
+ 
+Development:
+
+ * IGNITE_HOME environment variable must be set to Ignite installation directory.
+ * Once both libraries are built and installed, required headers are placed in the
+   "/usr/local/include/ignite" directory.
+ * Apache Ignite C++ depends on jni.h file located inside ${JAVA_HOME}/include directory.
+   Add this directory to headers search path: "-I${JAVA_HOME}/include".
+ * Library is placed in the "/usr/local/lib" directory. Link it to your project: "-lignite".
+ * Ignite depends on "libjvm.so" library shipped with Java. Typically this library is located inside
+   $JAVA_HOME/jre/lib/amd64/server directory. Ensure that LD_LIBRARY_PATH environment variable points to this directory.
+ * To start Apache Ignite as a standalone node or Windows service use ignite
+
+ 
+Windows info
+===============
+
+Files list:
 
  * ignite.exe - executable to start standalone Ignite C++ node.
  * ignite.core.dll - Ignite C++ API library.
+ 
+Development:
 
+ * IGNITE_HOME environment variable must be set to Ignite installation directory.
+ * Update Include Directories in Project Properties with paths to:
+   * $(IGNITE_HOME)\platforms\cpp\core\include
+   * $(IGNITE_HOME)\platforms\cpp\core\os\win\include
+   * $(IGNITE_HOME)\platforms\cpp\common\include
+   * $(IGNITE_HOME)\platforms\cpp\common\os\win\include
+   * $(JAVA_HOME)\include
+   * $(JAVA_HOME)\include\win32
+ * Update Library Directories with path to the built binaries
+ * Update Linker\Input\Additional Dependencies in Project Properties with path to
+   * ignite.common.lib
+   * ignite.core.lib
+ * Make sure that your application is aware about ignite.common.dll and ignite.core.dll libraries. The easiest way
+   to achieve this is to either make sure these files are in %PATH%, or to put them into the output directory of
+   your project with help of PostBuild events.
+ * To start Apache Ignite as a standalone node or Windows service use ignite.exe
\ No newline at end of file


[03/12] ignite git commit: IGNITE-2296

Posted by nt...@apache.org.
IGNITE-2296


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/fe44a566
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/fe44a566
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/fe44a566

Branch: refs/heads/ignite-gg-10837
Commit: fe44a566079504038627a8d2a4bf74b28e1dbb60
Parents: dd0a8d3
Author: Anton Vinogradov <av...@apache.org>
Authored: Mon Dec 28 13:41:01 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 13:41:01 2015 +0300

----------------------------------------------------------------------
 .../ignite/internal/processors/rest/protocols/http/jetty/rest.html | 2 +-
 modules/scalar-2.10/pom.xml                                        | 2 +-
 modules/scalar/pom.xml                                             | 2 +-
 parent/pom.xml                                                     | 2 +-
 4 files changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/fe44a566/modules/rest-http/src/main/java/org/apache/ignite/internal/processors/rest/protocols/http/jetty/rest.html
----------------------------------------------------------------------
diff --git a/modules/rest-http/src/main/java/org/apache/ignite/internal/processors/rest/protocols/http/jetty/rest.html b/modules/rest-http/src/main/java/org/apache/ignite/internal/processors/rest/protocols/http/jetty/rest.html
index a487921..f78d26a 100644
--- a/modules/rest-http/src/main/java/org/apache/ignite/internal/processors/rest/protocols/http/jetty/rest.html
+++ b/modules/rest-http/src/main/java/org/apache/ignite/internal/processors/rest/protocols/http/jetty/rest.html
@@ -55,7 +55,7 @@
     <br>
     <br>
     <center>
-        <a class="img_link" href="https://apache.org/projects/ignite.html" title="Apache Software Foundation">
+        <a class="img_link" href="https://ignite.apache.org" title="Apache Software Foundation">
             <img src="http://ignite.apache.org/images/logo3.png" alt="Ignite - In-Memory Data Fabric">
         </a>
         <p>

http://git-wip-us.apache.org/repos/asf/ignite/blob/fe44a566/modules/scalar-2.10/pom.xml
----------------------------------------------------------------------
diff --git a/modules/scalar-2.10/pom.xml b/modules/scalar-2.10/pom.xml
index 0cc030d..62c65f9 100644
--- a/modules/scalar-2.10/pom.xml
+++ b/modules/scalar-2.10/pom.xml
@@ -158,7 +158,7 @@
                                             <!--<td>-->
                                                 <!--<nobr>Ignite&#153; - Scalar DSL, ver. <strong>${project.version}</strong></nobr>-->
                                                 <!--<br>-->
-                                                <!--<a target=_blank href="https://apache.org/projects/ignite.html"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>-->
+                                                <!--<a target=_blank href="https://ignite.apache.org"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>-->
                                             <!--</td>-->
                                         <!--</tr>-->
                                         <!--</table>-->

http://git-wip-us.apache.org/repos/asf/ignite/blob/fe44a566/modules/scalar/pom.xml
----------------------------------------------------------------------
diff --git a/modules/scalar/pom.xml b/modules/scalar/pom.xml
index 8a503e4..c5886ae 100644
--- a/modules/scalar/pom.xml
+++ b/modules/scalar/pom.xml
@@ -143,7 +143,7 @@
                                             <td>
                                                 <nobr>Ignite&#153; - Scalar DSL, ver. <strong>${project.version}</strong></nobr>
                                                 <br>
-                                                <a target=_blank href="https://apache.org/projects/ignite.html"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>
+                                                <a target=_blank href="https://ignite.apache.org"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>
                                             </td>
                                         </tr>
                                         </table>

http://git-wip-us.apache.org/repos/asf/ignite/blob/fe44a566/parent/pom.xml
----------------------------------------------------------------------
diff --git a/parent/pom.xml b/parent/pom.xml
index f665d40..b7b417b 100644
--- a/parent/pom.xml
+++ b/parent/pom.xml
@@ -448,7 +448,7 @@
                                                 <tbody style="padding: 0; margin: 0">
                                                     <tr style="padding: 0; margin: 0">
                                                         <td>
-                                                            <a target=_blank href="https://apache.org/projects/ignite.html"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>
+                                                            <a target=_blank href="https://ignite.apache.org"><nobr>2015 Copyright &#169; Apache Software Foundation</nobr></a>
                                                         </td>
                                                     </tr>
                                                 </tbody>


[02/12] ignite git commit: release-sources & dotnet doc fix

Posted by nt...@apache.org.
release-sources & dotnet doc fix


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/dd0a8d3a
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/dd0a8d3a
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/dd0a8d3a

Branch: refs/heads/ignite-gg-10837
Commit: dd0a8d3acc2696db3404f7708bf27e34c7456b07
Parents: 939a170
Author: Anton Vinogradov <av...@apache.org>
Authored: Mon Dec 28 12:39:04 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 12:39:04 2015 +0300

----------------------------------------------------------------------
 assembly/release-sources.xml | 79 +++++++++++++++++++++++++++++++++++++++
 modules/clients/pom.xml      |  2 +-
 pom.xml                      | 23 +++++++-----
 3 files changed, 93 insertions(+), 11 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/dd0a8d3a/assembly/release-sources.xml
----------------------------------------------------------------------
diff --git a/assembly/release-sources.xml b/assembly/release-sources.xml
new file mode 100644
index 0000000..96e54f9
--- /dev/null
+++ b/assembly/release-sources.xml
@@ -0,0 +1,79 @@
+<?xml version='1.0' encoding='UTF-8'?>
+
+<!--
+  Licensed to the Apache Software Foundation (ASF) under one or more
+  contributor license agreements.  See the NOTICE file distributed with
+  this work for additional information regarding copyright ownership.
+  The ASF licenses this file to You under the Apache License, Version 2.0
+  (the "License"); you may not use this file except in compliance with
+  the License.  You may obtain a copy of the License at
+
+       http://www.apache.org/licenses/LICENSE-2.0
+
+  Unless required by applicable law or agreed to in writing, software
+  distributed under the License is distributed on an "AS IS" BASIS,
+  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+  See the License for the specific language governing permissions and
+  limitations under the License.
+-->
+
+<assembly>
+    <id>source-release</id>
+    <formats>
+        <format>zip</format>
+    </formats>
+
+    <fileSets>
+        <!-- main project directory structure -->
+        <fileSet>
+            <directory>.</directory>
+            <outputDirectory>/</outputDirectory>
+            <useDefaultExcludes>true</useDefaultExcludes>
+            <excludes>
+                <!-- build output -->
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/).*${project.build.directory}.*]</exclude>
+
+                <!-- NOTE: Most of the following excludes should not be required
+                     if the standard release process is followed. This is because the
+                     release plugin checks out project sources into a location like
+                     target/checkout, then runs the build from there. The result is
+                     a source-release archive that comes from a pretty clean directory
+                     structure.
+
+                     HOWEVER, if the release plugin is configured to run extra goals
+                     or generate a project website, it's definitely possible that some
+                     of these files will be present. So, it's safer to exclude them.
+                -->
+
+                <!-- IDEs -->
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?maven-eclipse\.xml]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.project]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.classpath]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?[^/]*\.iws]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.idea(/.*)?]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?out(/.*)?]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?[^/]*\.ipr]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?[^/]*\.iml]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.settings(/.*)?]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.externalToolBuilders(/.*)?]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.deployables(/.*)?]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?\.wtpmodules(/.*)?]</exclude>
+
+                <!-- misc -->
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?cobertura\.ser]</exclude>
+
+                <!-- release-plugin temp files -->
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?pom\.xml\.releaseBackup]</exclude>
+                <exclude>%regex[(?!((?!${project.build.directory}/)[^/]+/)*src/)(.*/)?release\.properties]</exclude>
+
+                <!-- dotnet assemblies -->
+                <exclude>modules/platforms/dotnet/bin/**</exclude>
+            </excludes>
+        </fileSet>
+        <!-- license, readme, etc. calculated at build time -->
+        <fileSet>
+            <directory>${project.build.directory}/maven-shared-archive-resources/META-INF</directory>
+            <outputDirectory>/</outputDirectory>
+        </fileSet>
+    </fileSets>
+</assembly>

http://git-wip-us.apache.org/repos/asf/ignite/blob/dd0a8d3a/modules/clients/pom.xml
----------------------------------------------------------------------
diff --git a/modules/clients/pom.xml b/modules/clients/pom.xml
index 1f4555f..faef4a4 100644
--- a/modules/clients/pom.xml
+++ b/modules/clients/pom.xml
@@ -142,7 +142,7 @@
             <id>docs</id>
             <activation>
                 <property>
-                    <name>!skipClientDocs</name>
+                    <name>clientDocs</name>
                 </property>
             </activation>
             <build>

http://git-wip-us.apache.org/repos/asf/ignite/blob/dd0a8d3a/pom.xml
----------------------------------------------------------------------
diff --git a/pom.xml b/pom.xml
index 4bdad1e..3457c30 100644
--- a/pom.xml
+++ b/pom.xml
@@ -476,25 +476,28 @@
                 <plugins>
                     <plugin>
                         <artifactId>maven-assembly-plugin</artifactId>
-                        <dependencies>
-                            <dependency>
-                                <groupId>org.apache.apache.resources</groupId>
-                                <artifactId>apache-source-release-assembly-descriptor</artifactId>
-                                <version>1.0.4</version>
-                            </dependency>
-                        </dependencies>
                         <executions>
                             <execution>
+                                <!-- skip default -->
                                 <id>source-release-assembly</id>
+                                <goals>
+                                    <goal>single</goal>
+                                </goals>
+                                <configuration>
+                                    <skipAssembly>true</skipAssembly>
+                                </configuration>
+                            </execution>
+                            <execution>
+                                <id>source-release-assembly-ignite</id>
                                 <phase>package</phase>
                                 <goals>
                                     <goal>single</goal>
                                 </goals>
                                 <configuration>
                                     <runOnlyAtExecutionRoot>true</runOnlyAtExecutionRoot>
-                                    <descriptorRefs>
-                                        <descriptorRef>${sourceReleaseAssemblyDescriptor}</descriptorRef>
-                                    </descriptorRefs>
+                                    <descriptors>
+                                        <descriptor>assembly/release-sources.xml</descriptor>
+                                    </descriptors>
                                     <tarLongFileMode>gnu</tarLongFileMode>
                                     <finalName>${project.artifactId}-${project.version}-src</finalName>
                                     <appendAssemblyId>false</appendAssemblyId>


[06/12] ignite git commit: IGNITE-2305: Splited C++ README into README and DEVNOTES.

Posted by nt...@apache.org.
IGNITE-2305: Splited C++ README into README and DEVNOTES.

Signed-off-by: Anton Vinogradov <av...@apache.org>


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/cdda4b52
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/cdda4b52
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/cdda4b52

Branch: refs/heads/ignite-gg-10837
Commit: cdda4b524eb4cf600b0da367b738603ef8a287db
Parents: 23d7e25
Author: isapego <is...@gridgain.com>
Authored: Mon Dec 28 14:56:25 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 15:50:40 2015 +0300

----------------------------------------------------------------------
 modules/platforms/cpp/DEVNOTES.txt | 84 +++++++++++++++++++++++++++++++++
 modules/platforms/cpp/README.txt   | 82 ++------------------------------
 2 files changed, 87 insertions(+), 79 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/cdda4b52/modules/platforms/cpp/DEVNOTES.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/DEVNOTES.txt b/modules/platforms/cpp/DEVNOTES.txt
new file mode 100644
index 0000000..c97d04c
--- /dev/null
+++ b/modules/platforms/cpp/DEVNOTES.txt
@@ -0,0 +1,84 @@
+Apache Ignite C++ Build Instructions
+====================================
+
+Building on Linux With Autotools
+----------------------------------
+
+Common Requirements:
+
+ * GCC, g++, autotools, automake, and libtool must be installed
+ * Java Development Kit (JDK) must be installed: https://java.com/en/download/index.jsp
+ * JAVA_HOME environment variable must be set pointing to Java installation directory.
+
+Building the library:
+
+ * Build Apache Ignite C++ helper "common" library:
+     * Navigate to the directory $IGNITE_HOME/platforms/cpp/common
+     * Execute the following commands one by one:
+         * libtoolize
+         * aclocal
+         * autoheader
+         * automake --add-missing
+         * autoreconf
+         * ./configure
+         * make
+         * make install
+ * Build Apache Ignite C++ library:
+     * Navigate to the directory $IGNITE_HOME/platforms/cpp/core
+     * Execute the following commands one by one:
+         * libtoolize
+         * aclocal
+         * autoheader
+         * automake --add-missing
+         * autoreconf
+         * ./configure
+         * make
+         * make install
+
+NOTE: "make install" command may require superuser privileges. In this case it must be
+executed as "sudo make install".
+
+Development:
+
+ * IGNITE_HOME environment variable must be set to Ignite installation directory.
+ * Once both libraries are built and installed, required headers are placed in the
+   "/usr/local/include/ignite" directory.
+ * Apache Ignite C++ depends on jni.h file located inside ${JAVA_HOME}/include directory.
+   Add this directory to headers search path: "-I${JAVA_HOME}/include".
+ * Library is placed in the "/usr/local/lib" directory. Link it to your project: "-lignite".
+ * Ignite depends on "libjvm.so" library shipped with Java. Typically this library is located inside
+   $JAVA_HOME/jre/lib/amd64/server directory. Ensure that LD_LIBRARY_PATH environment variable points to this directory.
+
+
+Building on Windows with Visual Studio (tm)
+----------------------------------
+
+Common Requirements:
+
+ * Microsoft Visual Studio (tm) 2010 or later
+ * Windows SDK 7.1
+ * Java Development Kit (JDK) must be installed: https://java.com/en/download/index.jsp
+ * JAVA_HOME environment variable must be set pointing to Java installation directory.
+
+Building the library:
+
+ * Open and build %IGNITE_HOME%\platforms\cpp\project\vs\ignite.sln (or ignite_86.sln if you are running
+   32-bit platform).
+
+Development:
+
+ * IGNITE_HOME environment variable must be set to Ignite installation directory.
+ * Update Include Directories in Project Properties with paths to:
+   * $(IGNITE_HOME)\platforms\cpp\core\include
+   * $(IGNITE_HOME)\platforms\cpp\core\os\win\include
+   * $(IGNITE_HOME)\platforms\cpp\common\include
+   * $(IGNITE_HOME)\platforms\cpp\common\os\win\include
+   * $(JAVA_HOME)\include
+   * $(JAVA_HOME)\include\win32
+ * Update Library Directories with path to the built binaries
+ * Update Linker\Input\Additional Dependencies in Project Properties with path to
+   * ignite.common.lib
+   * ignite.core.lib
+ * Make sure that your application is aware about ignite.common.dll and ignite.core.dll libraries. The easiest way
+   to achieve this is to either make sure these files are in %PATH%, or to put them into the output directory of
+   your project with help of PostBuild events.
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/cdda4b52/modules/platforms/cpp/README.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/README.txt b/modules/platforms/cpp/README.txt
index 7053964..74dec60 100644
--- a/modules/platforms/cpp/README.txt
+++ b/modules/platforms/cpp/README.txt
@@ -18,84 +18,8 @@ Support for the following will be added in next releases:
 
 Full source code is provided. Users should build the library for intended platform.
 
-Building on Linux With Autotools
-----------------------------------
+Output files list:
 
-Common Requirements:
+ * ignite.exe - executable to start standalone Ignite C++ node.
+ * ignite.core.dll - Ignite C++ API library.
 
- * GCC, g++, autotools, automake, and libtool must be installed
- * Java Development Kit (JDK) must be installed: https://java.com/en/download/index.jsp
- * JAVA_HOME environment variable must be set pointing to Java installation directory.
-
-Building the library:
-
- * Build Apache Ignite C++ helper "common" library:
-     * Navigate to the directory $IGNITE_HOME/platforms/cpp/common
-     * Execute the following commands one by one:
-         * libtoolize
-         * aclocal
-         * autoheader
-         * automake --add-missing
-         * autoreconf
-         * ./configure
-         * make
-         * make install
- * Build Apache Ignite C++ library:
-     * Navigate to the directory $IGNITE_HOME/platforms/cpp/core
-     * Execute the following commands one by one:
-         * libtoolize
-         * aclocal
-         * autoheader
-         * automake --add-missing
-         * autoreconf
-         * ./configure
-         * make
-         * make install
-
-NOTE: "make install" command may require superuser privileges. In this case it must be
-executed as "sudo make install".
-
-Development:
-
- * IGNITE_HOME environment variable must be set to Ignite installation directory.
- * Once both libraries are built and installed, required headers are placed in the
-   "/usr/local/include/ignite" directory.
- * Apache Ignite C++ depends on jni.h file located inside ${JAVA_HOME}/include directory.
-   Add this directory to headers search path: "-I${JAVA_HOME}/include".
- * Library is placed in the "/usr/local/lib" directory. Link it to your project: "-lignite".
- * Ignite depends on "libjvm.so" library shipped with Java. Typically this library is located inside
-   $JAVA_HOME/jre/lib/amd64/server directory. Ensure that LD_LIBRARY_PATH environment variable points to this directory.
-
-
-Building on Windows with Visual Studio (tm)
-----------------------------------
-
-Common Requirements:
-
- * Microsoft Visual Studio (tm) 2010 or later
- * Windows SDK 7.1
- * Java Development Kit (JDK) must be installed: https://java.com/en/download/index.jsp
- * JAVA_HOME environment variable must be set pointing to Java installation directory.
-
-Building the library:
-
- * Open and build %IGNITE_HOME%\platforms\cpp\project\vs\ignite.sln (or ignite_86.sln if you are running
-   32-bit platform).
-
-Development:
-
- * IGNITE_HOME environment variable must be set to Ignite installation directory.
- * Update Include Directories in Project Properties with paths to:
-   * $(IGNITE_HOME)\platforms\cpp\core\include
-   * $(IGNITE_HOME)\platforms\cpp\core\os\win\include
-   * $(IGNITE_HOME)\platforms\cpp\common\include
-   * $(IGNITE_HOME)\platforms\cpp\common\os\win\include
-   * $(JAVA_HOME)\include
-   * $(JAVA_HOME)\include\win32
- * Update Library Directories with path to the built binaries
- * Update Linker\Input\Additional Dependencies in Project Properties with path to
-   * ignite.common.lib
-   * ignite.core.lib
- * Make sure that your application is aware about ignite.common.dll and ignite.core.dll libraries. The easiest way
-   to achieve this is to either make sure these files are in %PATH%, or to put them into the output directory of
-   your project with help of PostBuild events.


[12/12] ignite git commit: Merge branch 'ignite-1.5' into ignite-gg-10837

Posted by nt...@apache.org.
Merge branch 'ignite-1.5' into ignite-gg-10837


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/7bc1501e
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/7bc1501e
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/7bc1501e

Branch: refs/heads/ignite-gg-10837
Commit: 7bc1501eb7933101f9ee70ac5907b75d07598a6e
Parents: 9f7b14e f97dc9f
Author: nikolay_tikhonov <nt...@gridgain.com>
Authored: Tue Dec 29 10:17:29 2015 +0300
Committer: nikolay_tikhonov <nt...@gridgain.com>
Committed: Tue Dec 29 10:17:29 2015 +0300

----------------------------------------------------------------------
 DEVNOTES.txt                                    | 11 +++
 RELEASE_NOTES.txt                               |  2 +
 assembly/release-fabric-base.xml                |  6 ++
 assembly/release-sources.xml                    | 79 ++++++++++++++++++++
 modules/clients/pom.xml                         |  2 +-
 .../apache/ignite/internal/IgniteKernal.java    |  7 +-
 .../ignite/internal/IgniteNodeAttributes.java   |  3 +
 .../processors/rest/GridRestProcessor.java      |  4 +
 .../rest/client/message/GridClientNodeBean.java |  4 +-
 .../plugin/security/AuthenticationContext.java  | 33 ++++++--
 modules/platforms/cpp/DEVNOTES.txt              | 59 +++++++++++++++
 modules/platforms/cpp/README.txt                | 64 ++++------------
 modules/platforms/cpp/project/vs/ignite.sln     |  6 +-
 modules/platforms/cpp/project/vs/ignite.slnrel  | 10 +++
 .../platforms/cpp/project/vs/ignite_x86.slnrel  | 10 +++
 modules/platforms/dotnet/Apache.Ignite.sln      |  5 +-
 modules/platforms/dotnet/DEVNOTES.txt           | 18 +++++
 .../rest/protocols/http/jetty/rest.html         |  2 +-
 modules/scalar-2.10/pom.xml                     |  2 +-
 modules/scalar/pom.xml                          |  2 +-
 parent/pom.xml                                  |  4 +-
 pom.xml                                         | 23 +++---
 22 files changed, 276 insertions(+), 80 deletions(-)
----------------------------------------------------------------------



[09/12] ignite git commit: IGNITE-2306: CPP: Added standalone node project to published solutions.

Posted by nt...@apache.org.
IGNITE-2306: CPP: Added standalone node project to published solutions.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/46b8f01d
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/46b8f01d
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/46b8f01d

Branch: refs/heads/ignite-gg-10837
Commit: 46b8f01d2a73811c9a3fcfa5c0e0e6c713d9c231
Parents: f023c05
Author: vozerov-gridgain <vo...@gridgain.com>
Authored: Mon Dec 28 16:27:01 2015 +0300
Committer: vozerov-gridgain <vo...@gridgain.com>
Committed: Mon Dec 28 16:27:01 2015 +0300

----------------------------------------------------------------------
 assembly/release-fabric-base.xml | 6 ++++++
 1 file changed, 6 insertions(+)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/46b8f01d/assembly/release-fabric-base.xml
----------------------------------------------------------------------
diff --git a/assembly/release-fabric-base.xml b/assembly/release-fabric-base.xml
index 21be995..5be9f8f 100644
--- a/assembly/release-fabric-base.xml
+++ b/assembly/release-fabric-base.xml
@@ -119,6 +119,12 @@
             <outputDirectory>/platforms/cpp/core</outputDirectory>
         </fileSet>
 
+        <!-- Move CPP "ignite" module. -->
+        <fileSet>
+            <directory>modules/platforms/cpp/ignite</directory>
+            <outputDirectory>/platforms/cpp/ignite</outputDirectory>
+        </fileSet>
+
         <!-- Move CPP examples. -->
         <fileSet>
             <directory>modules/platforms/cpp/examples</directory>
diff --git a/modules/core/src/main/java/org/apache/ignite/plugin/security/AuthenticationContext.java b/modules/core/src/main/java/org/apache/ignite/plugin/security/AuthenticationContext.java
index 16e282d..91f3379 100644
--- a/modules/core/src/main/java/org/apache/ignite/plugin/security/AuthenticationContext.java
+++ b/modules/core/src/main/java/org/apache/ignite/plugin/security/AuthenticationContext.java
@@ -18,6 +18,8 @@
 package org.apache.ignite.plugin.security;
 
 import java.net.InetSocketAddress;
+import java.util.Collections;
+import java.util.Map;
 import java.util.UUID;
 
 /**
@@ -31,11 +33,14 @@ public class AuthenticationContext {
     private UUID subjId;
 
     /** Credentials. */
-    private SecurityCredentials credentials;
+    private SecurityCredentials creds;
 
     /** Subject address. */
     private InetSocketAddress addr;
 
+    /** */
+    private Map<String, Object> nodeAttrs;
+
     /**
      * Gets subject type.
      *
@@ -78,16 +83,16 @@ public class AuthenticationContext {
      * @return Security credentials.
      */
     public SecurityCredentials credentials() {
-        return credentials;
+        return creds;
     }
 
     /**
      * Sets security credentials.
      *
      * @param credentials Security credentials.
      */
-    public void credentials(SecurityCredentials credentials) {
-        this.credentials = credentials;
+    public void credentials(SecurityCredentials creds) {
+        this.creds = creds;
     }
 
     /**
@@ -107,4 +112,22 @@ public class AuthenticationContext {
     public void address(InetSocketAddress addr) {
         this.addr = addr;
     }
+
+    /**
+     * Gets node attributes.
+     *
+     * @return Node attributes or empty map for {@link SecuritySubjectType#REMOTE_CLIENT}.
+     */
+    public Map<String, Object> nodeAttributes() {
+        return nodeAttrs != null ? nodeAttrs : Collections.<String, Object>emptyMap();
+    }
+
+    /**
+     * Sets node attributes.
+     *
+     * @param nodeAttrs Node attributes.
+     */
+    public void nodeAttributes(Map<String, Object> nodeAttrs) {
+        this.nodeAttrs = nodeAttrs;
+    }
 }
\ No newline at end of file


[04/12] ignite git commit: IGNITE-2305

Posted by nt...@apache.org.
IGNITE-2305


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/23d7e251
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/23d7e251
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/23d7e251

Branch: refs/heads/ignite-gg-10837
Commit: 23d7e2515056b3c37b8922b6cfca4cb18d86aaf7
Parents: fe44a56
Author: Anton Vinogradov <av...@apache.org>
Authored: Mon Dec 28 14:01:43 2015 +0300
Committer: Anton Vinogradov <av...@apache.org>
Committed: Mon Dec 28 14:01:43 2015 +0300

----------------------------------------------------------------------
 DEVNOTES.txt                               |  8 ++++++++
 modules/platforms/dotnet/Apache.Ignite.sln |  5 +++--
 modules/platforms/dotnet/DEVNOTES.txt      | 18 ++++++++++++++++++
 3 files changed, 29 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/23d7e251/DEVNOTES.txt
----------------------------------------------------------------------
@@ -78,16 +83,16 @@ public class AuthenticationContext {
      * Sets security credentials.
      *
-     * @param credentials Security credentials.
+     * @param creds Security credentials.
      */